@@ -22,8 +22,9 @@ import (
 
 func NewRouteCommand(p *commands.KnParams) *cobra.Command {
 	routeCmd := &cobra.Command{
-		Use:   "route",
-		Short: "Route command group",
+		Use:     "route",
+		Short:   "List and describe service routes (alias: routes)",
+		Aliases: []string{"routes"},
 	}
 	routeCmd.AddCommand(NewRouteListCommand(p))
 	routeCmd.AddCommand(NewRouteDescribeCommand(p))
