@@ -29,6 +29,7 @@ import (
 	servinglib "knative.dev/client/pkg/serving"
 	"knative.dev/client/pkg/util"
 	"knative.dev/client/pkg/wait"
+	network "knative.dev/networking/pkg"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -215,6 +216,7 @@ func TestServiceUpdateCommand(t *testing.T) {
 	origTemplate := &orig.Spec.Template
 
 	err := servinglib.UpdateContainerCommand(origTemplate, "./start")
+	assert.NilError(t, err)
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
 		"service", "update", "foo", "--cmd", "/app/start", "--no-wait"})
@@ -527,6 +529,7 @@ func TestServiceUpdateDoesntPinToDigestWhenUnAsked(t *testing.T) {
 
 	template := orig.Spec.Template
 	err := servinglib.UpdateImage(&template, "gcr.io/foo/bar:baz")
+	assert.NilError(t, err)
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
 		"service", "update", "foo", "-e", "TARGET=Awesome", "--no-lock-to-digest", "--no-wait"})
@@ -751,9 +754,9 @@ func TestServiceUpdateLabelExisting(t *testing.T) {
 
 func TestServiceUpdateNoClusterLocal(t *testing.T) {
 	original := newEmptyService()
-	original.ObjectMeta.Labels = map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}
+	original.ObjectMeta.Labels = map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}
 	originalTemplate := &original.Spec.Template
-	originalTemplate.ObjectMeta.Labels = map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}
+	originalTemplate.ObjectMeta.Labels = map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}
 
 	action, updated, _, err := fakeServiceUpdate(original, []string{
 		"service", "update", "foo", "--no-cluster-local", "--no-wait"})
@@ -791,9 +794,9 @@ func TestServiceUpdateNoClusterLocalOnPublicService(t *testing.T) {
 //TODO: add check for template name not changing when issue #646 solution is merged
 func TestServiceUpdateNoClusterLocalOnPrivateService(t *testing.T) {
 	original := newEmptyService()
-	original.ObjectMeta.Labels = map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}
+	original.ObjectMeta.Labels = map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}
 	originalTemplate := &original.Spec.Template
-	originalTemplate.ObjectMeta.Labels = map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}
+	originalTemplate.ObjectMeta.Labels = map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}
 
 	action, updated, _, err := fakeServiceUpdate(original, []string{
 		"service", "update", "foo", "--cluster-local", "--no-wait"})
@@ -804,7 +807,7 @@ func TestServiceUpdateNoClusterLocalOnPrivateService(t *testing.T) {
 		t.Fatalf("Bad action %v", action)
 	}
 
-	expected := map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}
+	expected := map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}
 	actual := updated.ObjectMeta.Labels
 	assert.DeepEqual(t, expected, actual)
 
